#!/bin/bash
# update_all.sh: updates webstats for all configured sites

# Author: Maurizio Pinotti <maurizio@pinottinet.com>
# Date: March 2006
# Updated: May 2006

# Parameters: $ANALOG_HOME $RMAGIC_HOME $WEBSTATS_HOME

# Path to analog exacutable and .cfg files
ANALOG_HOME=/cineca/devel/analog-6.0
if [ -n "$1" ]; then ANALOG_HOME=$1; fi
# Path to Report Magic executable and .ini files
RMAGIC_HOME=/cineca/devel/rmagic-2.21
if [ -n "$2" ]; then RMAGIC_HOME=$2; fi
# Path to Webstats home
WEBSTATS_HOME=/cineca/web/webstats-dev
if [ -n "$3" ]; then WEBSTATS_HOME=$3; fi
# Path to current location (used by rmagic to save html output)
WEBSTATS_PATH=`pwd`/htdocs

export ANALOG_HOME
export RMAGIC_HOME
export WEBSTATS_HOME
export WEBSTATS_PATH

# You can add new sites in a couple of steps: 
# 1) create a new .cfg file in $ANALOG_HOME/conf/
# 2) create a new .ini file in $RMAGIC_HOME/conf/
# 3) create a new .conf gile in $WEBSTATS_HOME/conf/
# These steps should not be done manually but through Web interface

# List all configured sites
cd $WEBSTATS_HOME/conf
for site in * 
do
	# Remove file extension
	sname=${site%.*}
	# For each site update webstats
	$ANALOG_HOME/update_analog.sh $ANALOG_HOME $sname
	if [ $? -gt 0 ]; then exit 1; fi
	$RMAGIC_HOME/update_rmagic.sh $RMAGIC_HOME $sname
	if [ $? -gt 0 ]; then exit 1; fi
	echo
done

# Save timestamp
cd ..
date > update_all.run

exit 0



