### webstats.py: Manage Analog's and Report Magic's config files via Zope/Plone.

### Author: Maurizio Pinotti
### Date: March 2006
### Updated: May 2006



### Imports
import os
from stat import *
import datetime
import shutil

from Products.Webstats.config import *
base_path = "./Products/Webstats/"
webstats_path = base_path+"webstats"+os.path.sep
webstats_conf_path = webstats_path+"conf/"+os.path.sep



### Version Control
__version__ = open(base_path+"version.txt").readlines()[0] 
__doc__ = "Web interface to handle Analog's and Report Magic's configuration files."




  
"""
Calls the appropriate function based on the 'act' parameter
"""
def webstatsAct(self):
  # Get selected action
  act = self.REQUEST.get("act", "")
  
  # Check that the user is not trying to exploit this script
  site = self.REQUEST.get("site", "")
  if site.find("/") > -1 or site.find("\\") > -1 or site.find(".") > -1:
    return "WARNING: script has detected a possible exploit!"

  # Switch action and return appropriate function
  if act == "list" or act == "":
    return listCfg(self)
  elif act == "delete": 
    return deleteCfg(self)
  elif act == "edit": 
    return editCfg(self)
  elif act == "new": 
    return newCfg(self)
  elif act == "update": 
    return updateCfg(self)
  elif act == "view": 
    return viewCfg(self)
  elif act == "write": 
    return writeCfg(self)

  # We should not be here...
  return "ERROR: unsupported action."



"""
Shows the list of the avilable conf files.
"""
def listCfg(self):
  output = "<h2>Currently configured sites</h2>\n"

  # Javascript to confirm deletion 
  output += """
  <script type="text/javascript">
  function confirmCfgDelete(fname) { 
    return confirm("Really delete site "+fname+"?");
  }
  </script>\n
  """

  # Show config file list
  output += "<ul>\n"
  count = 0
  for f in os.listdir(webstats_conf_path):
    count = count + 1
    # Remove file extension
    (d, ext) = os.path.splitext(f)
    # Get title and description from webstats conf file
    wcf = open(webstats_conf_path+f, "r").readlines()
    title = wcf[0]
    descr = ""
    if len(wcf) > 1: descr = wcf[1]
    # Print line for this file
    output += "<li /><a href='?act=view&site=%s' title='Show stats for %s'>%s</a>&nbsp;&nbsp;&nbsp;" % (d, title, title)
    alt = "Edit %s configuration files" % (d)
    output += "<a href='?act=edit&site=%s'><img src='images/edit.gif' alt='%s' title='%s' border='0'></a>&nbsp;&nbsp;" % (d, alt, alt)
    alt = "Delete %s configuration files" % (d)
    output += "<a href='?act=delete&site=%s' onClick='return confirmCfgDelete(\"%s\");'><img src='images/delete.gif' alt='%s' title='%s' border='0'></a>" % (d, d, alt, alt)
    output += "<br /><span class='documentByLine'>%s</span>" % (descr)
  # Close list
  output += "</ul><br>\n"

  # Check that at least one site is configured
  if count == 0:
    output += "<p><strong>No configured sites found.</strong></p><p>&nbsp;</p>"
  
  # Link to edit global files
  output += "<p><img src='images/global.gif' alt='' title=''>&nbsp;Edit " 
  output += "<a href='?act=edit&site=global'>Analog and Report Magic global configuration</a>"
  output += "</p>\n"
  
  # Link to create a new config file
  output += "<p><img src='images/new.gif' title='' alt=''>&nbsp;Configure a <a href='?act=new'>new site</a></p>\n" 

  # Link to run update_all.sh
  last_run_file = webstats_path+"update_all.run"
  if os.path.exists(last_run_file):
    last_run_date = file(last_run_file).readline()
  else:
    last_run_date = "stats not yet updated"
  output += "<p><img src='images/update.gif' title='' alt=''>&nbsp;Last updated: %s (<a href='?act=update'>update now</a>)</p>\n" % (last_run_date)

  output += "<p>&nbsp;</p><p align='center' class='discreet'>Webstats Manager v%s by Maurizio Pinotti" % __version__

  return output



"""
Shows a textarea to edit .cfg, .ini and .conf.
"""
def editCfg(self):
  # Name of the site (or "global" to edit global config files)
  fname = self.REQUEST.site  
  
  output = "<h2>Editing site %s</h2>\n" % fname
  
  # For security reasons check that we are editing an existent file
  if not fname == "global" and not os.path.exists(webstats_conf_path+fname+".conf"): 
    return "ERROR: editing of <b>%s</b> not allowed" % fname

  # Template for the form 
  form_template = """
  <script type='text/javascript'>
  function toggle(element) {
    e = document.getElementById("fc_"+element);
    if (e.style.display == "none") e.style.display = "";
    else e.style.display = "none";
  }
  </script>
  <form action='?' method='POST'>
    #TEXTAREAS#
    <p>&nbsp;</p><p>&nbsp;</p>
    <input type='hidden' name='act' value='write' />
    <input type='hidden' name='fname' value='%s' />
    <input type='submit' value='Save all' /> &nbsp;&nbsp;
    <input type='button' value='Cancel' onClick="javascript:history.go(-1);" />
  </form>
  """ % (fname)

  # Template for the textareas
  textarea_template = """
  <p>Configuration file of #ELEMENT# &nbsp;&nbsp;&nbsp;
  <a href="javascript:toggle('#ELEMENT#')"><img src="images/shortcut.gif" border='0' alt='Show/hide edit area' /></a>
  </p><p>
  <div style='display:none' id='fc_#ELEMENT#'>
    <textarea name='#ELEMENT#_content' rows='15' wrap='soft' style='width:100%%;'>\n%s
    </textarea>
  </div>
  </p><p>&nbsp;</p>
  """
  
  # File to open  
  fconf = ["", "", ""]
  # Content of suche files
  fcontent = ["", "", ""]
  # Names of the textareas
  cname = ["analog", "rmagic", "webstats"]
  # Check if we are editing the triplet of a site or the global couple 
  if fname == "global":
    # Print edit form: we need 2 textareas
    fconf = [analog_path+"analog.cfg", rmagic_path+"rmagic.ini"]
    fcount = 2
  else:
    # Print edit form: we need 3 textareas
    fconf = [analog_conf_path+fname+".cfg", rmagic_conf_path+fname+".ini", webstats_conf_path+fname+".conf"]
    fcount = 3

  # Open analog, rmagic and webstats configuration file
  textareas = ""
  for idx in range(0, fcount):
    f = file(fconf[idx], "r")
    fstat = os.stat(fconf[idx])
    fcontent[idx] = f.read(fstat[ST_SIZE])
    f.close()
    # Fix HTML tags
    fcontent[idx] = fcontent[idx].replace("<", "&lt;").replace(">", "&gt;").rstrip()
    # Print output
    textareas += textarea_template.replace("#ELEMENT#", cname[idx]) % fcontent[idx] 

  # Build up all together
  output += form_template.replace("#TEXTAREAS#", textareas)
 
  return output



"""
Writes the content of the textareas on the disk in the appropriate locations
"""
def writeCfg(self):
  #return self.REQUEST

  # Get the fname (should be "global" or a site name)
  fname = self.REQUEST.get("fname", "")
  output = ""

  # Save POST content
  fcontent = [\
    self.REQUEST.get("analog_content", ""), \
    self.REQUEST.get("rmagic_content", ""), \
    self.REQUEST.get("webstats_content", "")]
  
  # Check which file are we editing
  if (fname == "global"):
    fconf = [analog_path+"analog.cfg", rmagic_path+"rmagic.ini"]
    fcount = 2
  else:
    fconf = [analog_conf_path+fname+".cfg", rmagic_conf_path+fname+".ini", webstats_conf_path+fname+".conf"]
    fcount = 3

  # Create directory if required
  createfolder = self.REQUEST.get("createfolder", 0)
  if createfolder and fname:
    (dname, ext) = os.path.splitext(fname)
    dname = os.path.join(html_path, dname)
    try:
      if not os.path.isdir(dname):
        os.mkdir(dname)
      # Create index.html
      src = os.path.join(webstats_path, "default.html")
      dst = os.path.join(dname, "index.html")
      shutil.copyfile(src, dst)
    except IOError, OSError:
      output += "<p>ERROR: Cannot create directory <b>%s</b> or nested index file!</p>" % dname
      output += "<p><a href='?'>Go back to sites index</a></p>"
      return output
  
  output = "<h2>Saving site %s</h2>\n" % fname
  
  try:
    # Save file on disk
    for idx in range(0, fcount): 
      #output += "Saving %s...<br />" % fcontent[idx]
      f = file(fconf[idx], "w")
      f.write(fcontent[idx])
      f.close()
    output += "<p>All files successfully saved!</p>"
  except IOError:
    output += "<p>ERROR: IOError while saving files!</p>"
    
  if createfolder:
    output += "<p><a href='?act=edit&site=%s'>Review files for further modifications</p>" % fname
  output += "<p><a href='?'>Go back to sites index</a></p>"
  
  return output



"""
Deletes the files associated to specified site
"""
def deleteCfg(self):
  # Name  of the site to delete
  fname = self.REQUEST.site  
  
  output = "<h2>Deleting site %s</h2>\n" % fname
  
  try:
    # Files to delete: analog's .cfg, rmagic's .ini and webstats' .conf 
    os.unlink(os.path.join(analog_conf_path, fname+".cfg"))
    os.unlink(os.path.join(rmagic_conf_path, fname+".ini"))
    os.unlink(os.path.join(webstats_conf_path, fname+".conf"))
    output += "<p>Site successfully deleted!</p>"
    # Additionally, remove the HTML directory for this site
    dname = os.path.join(html_path, fname)
    shutil.rmtree(dname)
  except IOError, OSError:
    # Less! 
    output += "<p>ERROR: IOError while deleting files!</p>"
    
  output += "<p><a href='?'>Go back to sites index</a></p>"
  
  return output



"""
Wizard to create a new set of config files (analog+rmagic+webstats)
"""
def newCfg(self):
  fname = self.REQUEST.get("fname", "")
  output = "";

  # If no name is given then ask
  if not fname:
    output = "<h2>Configuring new site - Step 1/2</h2>\n"
    output += r"""
    <form action='?' method='POST'>
    <input type='hidden' name='act' value='new'>
    <p>File name:&nbsp;<input type='textfield' name='fname' value='newsite' cols='15' /><br />
    <span class='documentByLine'>Name used for the set of conf files (analog, rmagic and webstats), this follows normal UNIX filename rules (es. <em>hpc</em>)</span></p>
    <p>Site name:&nbsp;<input type='textfield' name='sname' value='New Site' cols='15' /><br />
    <span class='documentByLine'>Name used to identify this site versus human race (es. <em>H.P.C.</em>)</span></p>
    <p>Site description:&nbsp;<input type='textfield' name='descr' value='' cols='40' /><br />
    <span class='documentByLine'>Description used in the main page (es. <em>High Performace Computing</em>)</span></p>
    <p>Log type:&nbsp;<input type="radio" name='logtype' value='shared' checked>shared <input type="radio" name="logtype" value='dedicated'>dedicated<br />
    <span class='documentByLine'>Check "shared" option for sites logging to <em>/cineca/web/log/</em>, "dedicated" for sites logging to <em>/cineca/web/*/log</em></span></p>
    <p>&nbsp;</p>
    <input type='submit' value='Next' />&nbsp;&nbsp;
    <input type='button' value='Cancel' onClick="javascript:history.go(-1);" />
    </form>
    """
    return output
  else: 
    output = "<h2>Configuring new site - Step 2/2</h2>\n"
    
  # Check that fname is valid and that it does not exist
  err = ""
  if fname == "images" or fname == "global":
    err += "The names 'global' and 'images' are reserved for Webstats Manager.<br />"
  if os.path.isfile(os.path.join(analog_conf_path, fname+".cfg")):
    err += "File '%s.cfg' already exists.<br />" % fname
  if os.path.isfile(os.path.join(rmagic_conf_path, fname+".ini")):
    err += "File '%s.ini' already exists.<br />" % fname
  if os.path.isfile(os.path.join(webstats_conf_path, fname+".conf")):
    err += "File '%s.conf' already exists.<br />" % fname
  if not err == "":
    output = "<h2>ERROR: cannot create on or more file(s)</h2>\n"
    output += "<p>"+err+"</p>\n"
    output += "<p>&nbsp;</p><p><input type='button' value='Back' onClick='javascript:history.go(-1);'></p>"
    return output
    
  # Set some default values...
  author = self.REQUEST.get("AUTHENTICATED_USER", "anonymous")
  date = datetime.datetime.now().ctime()
  sname = self.REQUEST.get("sname", fname.capitalize())
  surl = "http://"+fname+".cineca.it"
  if self.REQUEST.get("logtype", "") == "shared":
    slog = "/cineca/web/log/access.log*"
    vhost_comment = ""
  else:
    slog = "/cineca/web/"+fname+"/log/access.log*"
    vhost_comment = "#"
  descr = self.REQUEST.get("descr", " ")

  # Wizard javascript per la creazione del file .cfg
  output += r"""
  <script type="text/javascript">
  function cfgWizard(reports_path, htdocs_path, log_path, vhost_comment) { 
    // ------------------ ANALOG 
    src = document.cfg_wizard;
    cfg = document.cfg_wizard.analog_content; 
    cfg.value = "";
    cfg.value += "# Configuration file for analog 6.0\n";
    cfg.value += "# See http://www.analog.cx/\n";
    cfg.value += "\n";
    cfg.value += "# Author: "+src.author.value+"\n";
    cfg.value += "# Date: "+src.date.value+"\n";
    cfg.value += "# Site: "+src.sname.value+" ("+src.surl.value+")\n";
    cfg.value += "\n";
    cfg.value += "# Name and URL of the site\n";
    cfg.value += "HOSTNAME \""+src.sname.value+"\"\n";
    cfg.value += "HOSTURL \""+src.surl.value+"\"\n";
    cfg.value += "\n";
    cfg.value += "# Log format and path (currently is vhost_common)\n";
    cfg.value += "# Referer: http://www.analog.cx/docs/logfmt.html\n";
    cfg.value += "LOGFORMAT (%j %j %j:%j:%j %j %j %v %s - - [%d/%M/%Y:%h:%n:%j %j] \"%j %r %j\" %c %b)\n";
    cfg.value += "LOGFILE "+src.slog.value+"\n";
    cfg.value += "\n";
    cfg.value += "# Virtual host filter\n";
    cfg.value += vhost_comment+"UNCOMPRESS *.gz \"./grepvhost.sh gzip "+src.fname.value+".cineca.it\"\n";
    cfg.value += vhost_comment+"UNCOMPRESS *.log \"./grepvhost.sh text "+src.fname.value+".cineca.it\"\n";
    cfg.value += "\n";
    cfg.value += "# Analog output\n";
    cfg.value += "OUTFILE "+reports_path+src.fname.value+".dat\n";
    
    cfg.value += "\n";

    // ------------------ RMAGIC
    ini = document.cfg_wizard.rmagic_content
    ini.value += "";
    ini.value += "# Configuration file for Report Magic 2.21\n";
    ini.value += "# See http://www.reportmagic.org/\n";
    ini.value += "\n";
    ini.value += "# Author: "+src.author.value+"\n";
    ini.value += "# Date: "+src.date.value+"\n";
    ini.value += "# Site: "+src.sname.value+" ("+src.surl.value+")\n";
    ini.value += "\n";
    ini.value += "[statistics]\n";
    ini.value += "\n";
    ini.value += "# Path to Analog output\n";
    ini.value += "File_In=reports/"+src.fname.value+".dat\n";
    ini.value += "Log_File=log/"+src.fname.value+".log\n";
    ini.value += "\n";
    ini.value += "[reports]\n";
    ini.value += "\n";
    ini.value += "# Path to Report Magic output\n";
    ini.value += "File_Out="+htdocs_path+src.fname.value+"/\n";
    ini.value += "\n";
    ini.value += "[website]\n";
    ini.value += "\n";
    ini.value += "# Site info\n";
    ini.value += "Base_URL="+src.surl.value+"\n";
    ini.value += "Title=\""+src.sname.value+"\"\n";

    // ------------------ WEBSTATS
    conf = document.cfg_wizard.webstats_content;
    conf.value = "";
    conf.value += src.sname.value+"\n";
    conf.value += src.descr.value+"\n";
  }
  </script>
  """
  cfgWizard = "javascript:cfgWizard(\"%s\",\"%s\",\"%s\",\"%s\");" % (rmagic_reports_path, html_path, slog, vhost_comment)
  

  # Form per l'immissione dei parametri personalizzabili
  output += """
  <form name='cfg_wizard' action="?" method="POST" onSubmit='%s'>
  <input type='hidden' name='act' value='write' />
  <input type='hidden' name='fname' value='%s' />
  <input type='hidden' name='sname' value='%s' />
  <input type='hidden' name='author' value='%s' />
  <input type='hidden' name='date' value='%s' />
  <input type='hidden' name='descr' value='%s' />

  <p>Site URL:&nbsp;<input type='textfield' name='surl' value='%s' cols='30' /><br />
  <span class='documentByLine'>Site URL, including protocol (usually http or https)</span></p>

  <p>Site logs:&nbsp;<input type='textfield' name='slog' value='%s' cols='50' /><br />
  <span class='documentByLine'>Path to site logs (es. <em>/cineca/web/hpc/log/access.log*</em>)</span></p>

  <br />
  <input type='submit' value='Create configuration files' />&nbsp;&nbsp;
  <input type='button' value='Back' onClick="javascript:history.go(-1);" />
  """ % (cfgWizard, fname, sname, author, date, descr, surl, slog)
  
  output += """  
  <input type='hidden' name='createfolder' value='1' />
  <input type='hidden' name='analog_content' value='' />
  <input type='hidden' name='rmagic_content' value='' />
  <input type='hidden' name='webstats_content' value='' />

  </form>\n
  """ 
  
  return output



"""
Shows the index of the requested site
"""
def viewCfg(self):
  # Name of the site to view
  site = self.REQUEST.get("site", "")
  href = html_url+site
  
  output = "<h2>Web site statistics of %s</h2>\n" % site
  
  # Show stats within iframe
  iframe = "width='100%' height='500' "
  iframe += "src='%s'" % href
  output += "<br /><iframe %s>&nbsp;</iframe><p>&nbsp;</p>\n" % (iframe) 
    
  output += "<p><a href='%s' target='_blank'>Full-screen view</a>&nbsp;&nbsp;&nbsp;" % href
  output += "<a href='?'>Go back to sites index</a></p>"
  
  return output



"""
Runs update_all.sh
"""
def updateCfg(self):
  output = "<h2>Updating Web statistics</h2>"
  params = analog_path+" "+rmagic_path+" "+webstats_path
  logfile = "./log/webstats.log"
  redir = ">"+logfile+" 2>"+logfile
  err = os.system(webstats_path+"update_all.sh "+params+" "+redir) 
  log = '<br />'.join(file(logfile, "r").readlines())
  output += "<blockquote>%s<br />&nbsp;</blockquote>" % log
  if err == 0:
    output += "<p>Webstats successfully updated.</p>"
  else:
    output += "<p>ERROR: exit code is %d</p>" % err

  output += "<p><a href='?'>Go back to sites index</a></p>"

  return output
